@@ -28,7 +28,7 @@ class CurrentPlaylistController(object):
 
         Read-only.
         """
-        return [copy(ct) for ct in self._cp_tracks]
+        return [copy(cp_track) for cp_track in self._cp_tracks]
 
     @property
     def tracks(self):
@@ -37,7 +37,14 @@ class CurrentPlaylistController(object):
 
         Read-only.
         """
-        return [ct[1] for ct in self._cp_tracks]
+        return [cp_track.track for cp_track in self._cp_tracks]
+
+    @property
+    def length(self):
+        """
+        Length of the current playlist.
+        """
+        return len(self._cp_tracks)
 
     @property
     def version(self):
@@ -116,9 +123,9 @@ class CurrentPlaylistController(object):
         matches = self._cp_tracks
         for (key, value) in criteria.iteritems():
             if key == 'cpid':
-                matches = filter(lambda ct: ct[0] == value, matches)
+                matches = filter(lambda ct: ct.cpid == value, matches)
             else:
-                matches = filter(lambda ct: getattr(ct[1], key) == value,
+                matches = filter(lambda ct: getattr(ct.track, key) == value,
                     matches)
         if len(matches) == 1:
             return matches[0]
@@ -129,6 +136,19 @@ class CurrentPlaylistController(object):
         else:
             raise LookupError(u'"%s" match multiple tracks' % criteria_string)
 
+    def index(self, cp_track):
+        """
+        Get index of the given (CPID integer, :class:`mopidy.models.Track`)
+        two-tuple in the current playlist.
+
+        Raises :exc:`ValueError` if not found.
+
+        :param cp_track: track to find the index of
+        :type cp_track: two-tuple (CPID integer, :class:`mopidy.models.Track`)
+        :rtype: int
+        """
+        return self._cp_tracks.index(cp_track)
+
     def move(self, start, end, to_position):
         """
         Move the tracks in the slice ``[start:end]`` to ``to_position``.
@@ -168,7 +188,6 @@ class CurrentPlaylistController(object):
 
         :param criteria: on or more criteria to match by
         :type criteria: dict
-        :type track: :class:`mopidy.models.Track`
         """
         cp_track = self.get(**criteria)
         position = self._cp_tracks.index(cp_track)
@@ -204,6 +223,19 @@ class CurrentPlaylistController(object):
         self._cp_tracks = before + shuffled + after
         self.version += 1
 
+    def slice(self, start, end):
+        """
+        Returns a slice of the current playlist, limited by the given
+        start and end positions.
+
+        :param start: position of first track to include in slice
+        :type start: int
+        :param end: position after last track to include in slice
+        :type end: int
+        :rtype: two-tuple of (CPID integer, :class:`mopidy.models.Track`)
+        """
+        return [copy(cp_track) for cp_track in self._cp_tracks[start:end]]
+
     def _trigger_playlist_changed(self):
         logger.debug(u'Triggering playlist changed event')
         BackendListener.send('playlist_changed')
