@@ -1,10 +1,12 @@
 import os
 import subprocess
 import sys
-import unittest
 
 import mopidy
 
+from tests import unittest
+
+
 class HelpTest(unittest.TestCase):
     def test_help_has_mopidy_options(self):
         mopidy_dir = os.path.dirname(mopidy.__file__)
